function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useContext, useRef } from 'react';
import { DisplayErrorCtx } from './CustomForm';
const CustomFormField = ({
  label = null,
  value = null,
  onChange = () => {},
  type = 'text',
  selectValues = [],
  className = '',
  name = '',
  disabled = false,
  isValid = true,
  feedback = '',
  options = null,
  emptySelectOption = false,
  prefix = null,
  placeholder = '',
  fileSizeLimit = 2097152,
  hint = '',
  ...props
}) => {
  const displayError = useContext(DisplayErrorCtx);
  const renderFileInput = () => {
    const fileRef = useRef();
    return /*#__PURE__*/React.createElement("input", _extends({
      className: `form-control ${displayError && !isValid && 'is-invalid'}`,
      type: "file",
      onChange: _ => {
        if (fileRef.current.files[0].size < fileSizeLimit) {
          onChange(fileRef.current.files);
        } else {
          alert('Le fichier est trop volumineux');
          fileRef.current.value = '';
        }
      },
      disabled: disabled
    }, props, {
      ref: fileRef
    }));
  };
  const renderTextarea = () => /*#__PURE__*/React.createElement("textarea", _extends({
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    disabled: disabled,
    name: name,
    placeholder: placeholder
  }, props));
  const renderSelect = () => {
    const selectOptions = options == null ? selectValues : options;
    return /*#__PURE__*/React.createElement("select", _extends({}, props, {
      className: `form-control ${displayError && !isValid && 'is-invalid'}`,
      value: value,
      onChange: onChange,
      name: name,
      disabled: disabled,
      placeholder: placeholder
    }), emptySelectOption && /*#__PURE__*/React.createElement("option", {
      value: ''
    }), selectOptions.map(({
      value: val,
      label
    }, index) => /*#__PURE__*/React.createElement("option", {
      key: index,
      value: val
    }, label == null ? val : label)));
  };
  const renderRadio = () => {
    const radioName = Math.random() * 1000;
    return /*#__PURE__*/React.createElement("div", {
      className: `radios-container spaced-inline ${className}`
    }, options.map(({
      value: radioValue,
      label
    }, index) => {
      const radioId = Math.random() * 1000;
      return /*#__PURE__*/React.createElement("div", {
        className: "radio spaced-inline",
        key: index
      }, /*#__PURE__*/React.createElement("input", {
        type: "radio",
        name: radioName,
        value: radioValue,
        checked: radioValue === value,
        id: radioId,
        onChange: onChange
      }), /*#__PURE__*/React.createElement("label", {
        htmlFor: radioId
      }, label));
    }));
  };
  const renderInput = () => /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-control ${displayError && !isValid && 'is-invalid'}`,
    value: value,
    onChange: onChange,
    type: type,
    name: name,
    disabled: disabled,
    placeholder: placeholder
  }));
  const renderCheckbox = () => /*#__PURE__*/React.createElement("div", {
    className: "form-group form-check custom-checkbox"
  }, /*#__PURE__*/React.createElement("input", _extends({}, props, {
    className: `form-check-input ${displayError && !isValid && 'is-invalid'}`,
    checked: value,
    onChange: onChange,
    type: "checkbox",
    name: name,
    disabled: disabled
  })), /*#__PURE__*/React.createElement("label", {
    className: "form-check-label"
  }, label));
  return /*#__PURE__*/React.createElement("div", {
    className: `custom-form-field ${className}`
  }, label != null && type != 'checkbox' && /*#__PURE__*/React.createElement("label", null, typeof label === 'function' ? label() : label), /*#__PURE__*/React.createElement("div", {
    className: "input-group"
  }, prefix != null && /*#__PURE__*/React.createElement(React.Fragment, null, typeof prefix === 'function' ? prefix() : /*#__PURE__*/React.createElement("span", {
    className: "input-group-text"
  }, prefix)), type === 'select' ? renderSelect() : type === 'textarea' ? renderTextarea() : type === 'checkbox' ? renderCheckbox() : type === 'file' ? renderFileInput() : type === 'radio' ? renderRadio() : renderInput(), displayError && !isValid && feedback != '' && /*#__PURE__*/React.createElement("div", {
    className: "invalid-feedback"
  }, feedback)), hint != '' && /*#__PURE__*/React.createElement("small", null, hint));
};
export default /*#__PURE__*/React.forwardRef(CustomFormField);